# Printer API

The core printing functionality of PyRePrint.

## reprint

The main function for enhanced printing.

::: pyreprint.core.printer.reprint

## Printer Class

A configurable printer instance.

::: pyreprint.core.printer.Printer

## Utility Functions

### install_print

::: pyreprint.core.printer.install_print

### uninstall_print

::: pyreprint.core.printer.uninstall_print

